]> sigrok.org Git - libsigrok.git/blobdiff - sigrok.h
Change all sigrok_ prefixes to sr_.
[libsigrok.git] / sigrok.h
index 3d56106f44fdce14ed3dc5f0853118b0b9054d66..c25380af7ba8cc108484a679f4fe637089497020 100644 (file)
--- a/sigrok.h
+++ b/sigrok.h
@@ -48,10 +48,10 @@ extern "C" {
  * or reused for different #defines later. You can only add new #defines and
  * return codes, but never remove or redefine existing ones.
  */
-#define SIGROK_OK                 0 /* No error */
-#define SIGROK_ERR               -1 /* Generic/unspecified error */
-#define SIGROK_ERR_MALLOC        -2 /* Malloc/calloc/realloc error */
-#define SIGROK_ERR_SAMPLERATE    -3 /* Incorrect samplerate */
+#define SR_OK                 0 /* No error */
+#define SR_ERR               -1 /* Generic/unspecified error */
+#define SR_ERR_MALLOC        -2 /* Malloc/calloc/realloc error */
+#define SR_ERR_SAMPLERATE    -3 /* Incorrect samplerate */
 
 /* limited by uint64_t */
 #define MAX_NUM_PROBES 64
@@ -78,6 +78,7 @@ typedef int (*receive_data_callback) (int fd, int revents, void *user_data);
 enum {
        T_UINT64,
        T_CHAR,
+       T_NULL,
 };
 
 enum {
@@ -117,35 +118,46 @@ struct datafeed_header {
        int num_logic_probes;
 };
 
-struct input {
-       struct input_format *format;
+struct analog_probe {
+       uint8_t att;
+       uint8_t res;    /* Needs to be a power of 2, FIXME */
+       uint16_t val;   /* Max hardware ADC width is 16bits */
+};
+
+struct analog_sample {
+       uint8_t num_probes; /* Max hardware probes is 256 */
+       struct analog_probe probes[];
+};
+
+struct sr_input {
+       struct sr_input_format *format;
        char *param;
        struct device *vdevice;
 };
 
-struct input_format {
+struct sr_input_format {
        char *extension;
        char *description;
        int (*format_match) (const char *filename);
-       int (*init) (struct input *in);
-       int (*loadfile) (struct input *in, const char *filename);
+       int (*init) (struct sr_input *in);
+       int (*loadfile) (struct sr_input *in, const char *filename);
 };
 
-struct output {
-       struct output_format *format;
+struct sr_output {
+       struct sr_output_format *format;
        struct device *device;
        char *param;
        void *internal;
 };
 
-struct output_format {
+struct sr_output_format {
        char *extension;
        char *description;
        int df_type;
-       int (*init) (struct output *o);
-       int (*data) (struct output *o, char *data_in, uint64_t length_in,
+       int (*init) (struct sr_output *o);
+       int (*data) (struct sr_output *o, char *data_in, uint64_t length_in,
                     char **data_out, uint64_t *length_out);
-       int (*event) (struct output *o, int event_type, char **data_out,
+       int (*event) (struct sr_output *o, int event_type, char **data_out,
                      uint64_t *length_out);
 };
 
@@ -225,7 +237,7 @@ struct hwcap_option {
        char *shortname;
 };
 
-struct sigrok_device_instance {
+struct sr_device_instance {
        int index;
        int status;
        int instance_type;
@@ -239,7 +251,7 @@ struct sigrok_device_instance {
        };
 };
 
-/* sigrok_device_instance types */
+/* sr_device_instance types */
 enum {
        USB_INSTANCE,
        SERIAL_INSTANCE,
@@ -274,7 +286,7 @@ enum {
 
 /* Device info IDs */
 enum {
/* struct sigrok_device_instance for this specific device */
        DI_INSTANCE,
        /* The number of probes connected to this device */
        DI_NUM_PROBES,
@@ -330,9 +342,10 @@ struct session {
        GSList *devices;
        /* List of struct analyzer* */
        GSList *analyzers;
-       /* Datafeed callbacks */
+       /* list of receive_data_callback */
        GSList *datafeed_callbacks;
        GTimeVal starttime;
+       gboolean running;
 };
 
 #include "sigrok-proto.h"
@@ -274,7 +286,7 @@ enum {
 /* Device info IDs */
 enum {
-       /* struct sigrok_device_instance for this specific device */
+       /* struct sr_device_instance for this specific device */
        DI_INSTANCE,
        /* The number of probes connected to this device */